<?php

namespace Teknisa\CRM\Controller;

use Teknisa\CRM\Controller\TeknisaCrud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;
use Geral\Util\DateUtil;

class AuditoriaCadastrosController extends TeknisaCrud {
    
    protected $dataSourceGetAuditoriaCadastros = 'auditoriaCadastros';
    protected $parameterBagColumns = array('P_CRM_NRORGTRAB');
    
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag){
        $this->dataSourceManager = $dataSourceManager;
        $this->parameterBag = $parameterBag;
        parent::__construct($dataSourceManager, $parameterBag);
    }

        
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $arrayFieldsAuditoria = array('SEGMENTO', 'RAMO', 'MODODIVULGACAO', 'ENDERECO', 'TELEFONE', 'INTERLOCUTOR', 'P_CRM_NRORGTRAB');
            
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetAuditoriaCadastros);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData);
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );


        return $newFilterCriteria;
    }

}